@@ -1,8 +1,42 @@
+#' Eurostat web object.
+#'
+#' From Eurostat's webpage (see references):
+#' You can download individual datasets or the complete database by using the bulk download facility. 
+#' On the bulk download you will find:
+#' all information updated twice a day, at 11:00 and 23:00, (at this time the service is usually not available, K.W.)
+#' the datasets in tsv (tab separated values) (this is what is used by this R code, K.W.), 
+#' dft and sdmx format, which can be easily used to import the data in a tool of your choice,
+#' a manual containing all detailed information on the bulkdownload facility,
+#' the table of contents that includes the list of the datasets available,
+#' the "dictionaries" of all the coding systems used in the datasets.
+#'
+#' The eurostat_web() function returns a data object with three methods,
+#' "EurostatToc" which returns a data.frame of available datasets,
+#' "EurostatDicts" which returns a large data.frame of codes,
+#' "EurostatData" which returns the dataset for a given code.
+#'
+#' @return an object of class Mashup
+#' @references 
+#' \url{http://epp.eurostat.ec.europa.eu/}
+#'
+#' @examples
+#' getSlots("Eurostat")
+#' 
+#' @name Eurostat-class
+#' @rdname Eurostat-class
+#' @exportClass Eurostat
+setClass(
+  Class="Eurostat", 
+  contains="Mashup"
+)
+
 #' eurostat_data -- creates UrlData object for accessing Eurostat datasets.
 #'
-#' @rdname datamart-internal
-eurostat_data <- function() urldata(
-  template="http://epp.eurostat.ec.europa.eu/NavTree_prod/everybody/BulkDownloadListing?file=data%%2F%s.tsv.gz",
+#' @rdname Eurostat-class
+eurostat_data <- function() urldata3(
+  resource="EurostatData",
+  template="http://epp.eurostat.ec.europa.eu/NavTree_prod/everybody/BulkDownloadListing?file=data%2F$(code).tsv.gz",
+  code=NA, # required
   extract.fct= function(uri) {
     tf <- tempfile()
     content <- getBinaryURL(uri)
@@ -12,50 +46,25 @@ eurostat_data <- function() urldata(
   transform.fct=function(x) {
     res <- read.csv(gzfile(x), na.strings=c(": ", "p"), stringsAsFactor=FALSE, sep="\t")
     unlink(x)
-    code <- strhead(colnames(res)[[1]], -5)
-    code <- strsplit(code, "\\.")[[1]]
-    tm <- as.Date(paste(substring(tail(colnames(res),-1),2),1,1,sep="-0"))
-    nm <- gsub(",", ".", res[,1])
-    res <- res[,2:ncol(res)]
-    
-    res <- as.numeric(gsub("( s|,)", "", as.matrix(res)))
-    res <- matrix(res, nrow=length(tm), ncol=length(nm), byrow=TRUE)
-    res <- xts(res, tm)
-    names(res) <- nm
-    attr(res, "code") <- code
+    for(i in 2:ncol(res)) res[,i] <- as.numeric(gsub("( s|,)", "", res[,i]))
     return(res)
   }
 )
 
-#' eurostat_toc -- creates UrlData object for accessing Eurostat "table of contents", i.e. a description of datasets.
-#'
-#' @rdname datamart-internal
-eurostat_toc <- function() urldata(
-  template="http://epp.eurostat.ec.europa.eu/NavTree_prod/everybody/BulkDownloadListing?file=table_of_contents.xml",
-  #template="C:\\Dokumente und Einstellungen\\TravelMate\\Desktop\\table_of_contents.xml",
-  map.lst=list(Toc=""),
-  transform.fct=function(x) {
-    dat <- xmlParse(x)
-    namespaces <- c(
-      nt="urn:eu.europa.ec.eurostat.navtree",
-      xsi="http://www.w3.org/2001/XMLSchema-instance" 
-    )
-    nodes <- getNodeSet(dat, "//nt:leaf[@type='dataset']", namespaces=namespaces)
-    dat <- sapply(nodes, function(n) c(xmlValue(n[["code"]]), xmlValue(n[["title"]]), xmlValue(n[["dataStart"]]))) # this gets ignored: , xmlValue(n[["unit"]]))))
-    dat <- data.frame(code=dat[1,], title=dat[2,], dataStart=dat[3,], stringsAsFactors=FALSE)
-    return(dat)
-  },
-  scrape.lst=list(Toc=list(saveMode="w"))
-)
 
 #' eurostat_dicts -- creates UrlData object for accessing Eurostat "dictionaries", i.e. a description of indicators.
 #'
-#' @rdname datamart-internal
-eurostat_dicts <- function() urldata(
-  template="http://epp.eurostat.ec.europa.eu/NavTree_prod/everybody/BulkDownloadListing?sort=1&file=dic%%2Fall_dic.zip",
-  #template="file://C|\\Dokumente und Einstellungen\\TravelMate\\Desktop\\all_dic.zip",
-  map.lst=list(Dicts=""),
-  extract.fct=function(uri) {p <- file.path(tempdir(), "all_dic.zip"); if(download.file(uri, p)==0) p else ""}, 
+#' @rdname Eurostat-class
+eurostat_dicts <- function() urldata3(
+  resource="EurostatDicts",
+  template="http://epp.eurostat.ec.europa.eu/NavTree_prod/everybody/BulkDownloadListing?sort=1&file=dic%2Fall_dic.zip",
+  #template="C:\\Users\\weinert\\Desktop\\all_dic.zip",
+  extract.fct=function(uri) {
+    tf <- tempfile()
+    content <- getBinaryURL(uri)
+    writeBin(content, tf)
+    return(tf)
+  },
   transform.fct=function(x) {
     if(x=="") return(NULL)
     d <- dirname(x)
@@ -70,30 +79,34 @@ eurostat_dicts <- function() urldata(
     )
     dat <- Reduce(rbind, dat) # this is slow
     return(dat)
-  },
-  scrape.lst=list(Dicts=list(saveMode="w"))
+  }
 )
 
-#' Eurostat data object.
+#' eurostat_toc -- creates UrlData object for accessing Eurostat "table of contents", i.e. a description of datasets.
 #'
-#' From Eurostat's webpage (see references):
-#' You can download individual datasets or the complete database by using the bulk download facility. 
-#' On the bulk download you will find:
-#' - all information updated twice a day, at 11:00 and 23:00, (at this time the service is usually not available, K.W.)
-#' - the datasets in tsv (tab separated values) (this is what is used by this R code, K.W.), 
-#'   dft and sdmx format, which can be easily used to import the data in a tool of your choice,
-#' - a manual containing all detailed information on the bulkdownload facility,
-#' - the table of contents that includes the list of the datasets available,
-#' - the "dictionaries" of all the coding systems used in the datasets.
-#'
-#' @docType data
-#' @return an object of class Mashup
-#' @references 
-#' \url{http://epp.eurostat.ec.europa.eu/}
+#' @rdname Eurostat-class
+eurostat_toc <- function() urldata3(
+  resource="EurostatToc",
+  template="http://epp.eurostat.ec.europa.eu/NavTree_prod/everybody/BulkDownloadListing?file=table_of_contents.xml",
+  #template="C:\\Dokumente und Einstellungen\\TravelMate\\Desktop\\table_of_contents.xml",
+  extract.fct = xmlParse,
+  transform.fct=function(dat) {
+    namespaces <- c(
+      nt="urn:eu.europa.ec.eurostat.navtree",
+      xsi="http://www.w3.org/2001/XMLSchema-instance" 
+    )
+    nodes <- getNodeSet(dat, "//nt:leaf[@type='dataset']", namespaces=namespaces)
+    dat <- sapply(nodes, function(n) c(xmlValue(n[["code"]]), xmlValue(n[["title"]]), xmlValue(n[["dataStart"]]))) # this gets ignored: , xmlValue(n[["unit"]]))))
+    dat <- data.frame(code=dat[1,], title=dat[2,], dataStart=dat[3,], stringsAsFactors=FALSE)
+    return(dat)
+  }
+)
+
 #' @export
-eurostat <- function() mashup(
+#' @rdname Eurostat-class
+eurostat_web <- function() mashup(
   dat=eurostat_data(),
   toc=eurostat_toc(),
   dic=eurostat_dicts(),
-  dbname=file.path(tempdir(), "eurostat.db")
+  clss="Eurostat"
 )
