@@ -8,9 +8,11 @@
 #' @references 
 #' \url{http://stackoverflow.com/questions/13905098/how-to-get-the-longitude-and-latitude-coordinates-from-a-city-name-and-country-i}
 #' @export
-cityCoords <- function(country="DE") urldata(
-  template=paste("http://nominatim.openstreetmap.org/search?city=%s&countrycodes=",country,"&limit=9&format=json", sep=""),
-  map.fct=function(self, x) gsub(' ','%20',x), #remove space for URLs
+city_coords <- function(country="DE") urldata3(
+  resource="CityCoordinates",
+  template="http://nominatim.openstreetmap.org/search?city=$(city)&countrycodes=$(country)&limit=9&format=json",
+  country=country,
+  city=NA,
   extract.fct=fromJSON,
   transform.fct=function(x) if(is.vector(x)) c(lat=as.numeric(x[[1]]$lat), lon=as.numeric(x[[1]]$lon)) else c(NA, NA)
 )
